#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Test of Dojo tab container presentation."""

from macaroon.playback import *
import utils

sequence = MacroSequence()

#sequence.append(WaitForDocLoad())
sequence.append(PauseAction(5000))
sequence.append(KeyComboAction("Tab"))
sequence.append(PauseAction(5000))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Tab"))
sequence.append(utils.AssertPresentationAction(
    "1. Tab to tab list",
    ["BRAILLE LINE:  'Tab 2 page tab'",
     "     VISIBLE:  'Tab 2 page tab', cursor=1",
     "BRAILLE LINE:  'Focus mode'",
     "     VISIBLE:  'Focus mode', cursor=0",
     "SPEECH OUTPUT: 'Tab 2 page tab.'",
     "SPEECH OUTPUT: 'Focus mode' voice=system"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Right"))
sequence.append(utils.AssertPresentationAction(
    "2. Right arrow to next tab",
    ["BRAILLE LINE:  'Tab 2 page tab'",
     "     VISIBLE:  'Tab 2 page tab', cursor=1",
     "BRAILLE LINE:  'Tab 3 page tab'",
     "     VISIBLE:  'Tab 3 page tab', cursor=1",
     "SPEECH OUTPUT: 'Tab 3 page tab.'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Right"))
sequence.append(utils.AssertPresentationAction(
    "3. Right arrow to next tab",
    ["BRAILLE LINE:  'Inlined Sub TabContainer page tab'",
     "     VISIBLE:  'Inlined Sub TabContainer page ta', cursor=1",
     "SPEECH OUTPUT: 'Inlined Sub TabContainer page tab.'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Tab"))
sequence.append(utils.AssertPresentationAction(
    "4. Tab to contents",
    ["BRAILLE LINE:  'SubTab 2 page tab'",
     "     VISIBLE:  'SubTab 2 page tab', cursor=1",
     "SPEECH OUTPUT: 'SubTab 2 page tab.'"]))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
