#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

from macaroon.playback import *
import utils

sequence = MacroSequence()

#sequence.append(WaitForDocLoad())
sequence.append(PauseAction(5000))

# Work around some new quirk in Gecko that causes this test to fail if
# run via the test harness rather than manually.
sequence.append(KeyComboAction("<Control>r"))
sequence.append(KeyComboAction("<Control>Home"))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("a"))
sequence.append(utils.AssertPresentationAction(
    "1. a for next clickable",
    ["BRAILLE LINE:  'Hello'",
     "     VISIBLE:  'Hello', cursor=1",
     "SPEECH OUTPUT: 'Hello clickable'"]))

sequence.append(PauseAction(5000))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_Divide"))
sequence.append(PauseAction(5000))
sequence.append(utils.AssertPresentationAction(
    "2. KP_Divide to click on clickable",
    ["BRAILLE LINE:  'Goodbye cruel'",
     "     VISIBLE:  'Goodbye cruel', cursor=1",
     "SPEECH OUTPUT: 'Goodbye cruel clickable'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Alt><Shift>a"))
sequence.append(PauseAction(5000))
sequence.append(utils.AssertPresentationAction(
    "3. Alt+a for Activate button",
    ["BRAILLE LINE:  'runcthulhu.py application Clickables: 1 item found dialog'",
     "     VISIBLE:  'Clickables: 1 item found dialog', cursor=1",
     "BRAILLE LINE:  'runcthulhu.py application Clickables: 1 item found dialog table Clickable column header Goodbye cruel static'",
     "     VISIBLE:  'Goodbye cruel static', cursor=1",
     "SPEECH OUTPUT: 'Clickables: 1 item found'",
     "SPEECH OUTPUT: 'table with 1 row 2 columns'",
     "SPEECH OUTPUT: 'Goodbye cruel.'",
     "SPEECH OUTPUT: 'static.'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Alt>a"))
sequence.append(PauseAction(5000))
sequence.append(utils.AssertPresentationAction(
    "4. Alt+a for Activate button",
    ["BRAILLE LINE:  'Firefox application Firefox Nightly frame'",
     "     VISIBLE:  'Firefox Nightly frame', cursor=1",
     "BRAILLE LINE:  'Goodbye cruel'",
     "     VISIBLE:  'Goodbye cruel', cursor=1",
     "SPEECH OUTPUT: 'Firefox Nightly frame'",
     "SPEECH OUTPUT: 'Hello clickable'"]))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
