#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Test of toolbar output using."""

from macaroon.playback import *
import utils

sequence = MacroSequence()

sequence.append(KeyComboAction("<Control>f"))
sequence.append(TypeAction("Application class"))
sequence.append(KeyComboAction("Return"))
sequence.append(KeyComboAction("Return"))
sequence.append(KeyComboAction("Tab"))
sequence.append(PauseAction(3000))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Control>Tab"))
sequence.append(utils.AssertPresentationAction(
    "1. Push button initial focus",
    ["KNOWN ISSUE: The widgets on the toolbar no longer have accessible names, so Cthulhu cannot present them.",
     "BRAILLE LINE:  'gtk3-demo-application application Application Class frame push button'",
     "     VISIBLE:  'push button', cursor=1",
     "SPEECH OUTPUT: 'push button'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_Enter"))
sequence.append(utils.AssertPresentationAction(
    "2. Where Am I",
    ["BRAILLE LINE:  'gtk3-demo-application application Application Class frame push button'",
     "     VISIBLE:  'push button', cursor=1",
     "SPEECH OUTPUT: 'tool bar push button'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Right"))
sequence.append(utils.AssertPresentationAction(
    "3. Open triangle toggle button",
    ["BRAILLE LINE:  'gtk3-demo-application application Application Class frame & y Menu toggle button'",
     "     VISIBLE:  '& y Menu toggle button', cursor=1",
     "SPEECH OUTPUT: 'Menu toggle button not pressed'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_Enter"))
sequence.append(utils.AssertPresentationAction(
    "4. Open triangle toggle button Where Am I",
    ["BRAILLE LINE:  'gtk3-demo-application application Application Class frame & y Menu toggle button'",
     "     VISIBLE:  '& y Menu toggle button', cursor=1",
     "SPEECH OUTPUT: 'tool bar Menu toggle button not pressed'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Right"))
sequence.append(utils.AssertPresentationAction(
    "5. Next push button",
    ["BRAILLE LINE:  'gtk3-demo-application application Application Class frame push button'",
     "     VISIBLE:  'push button', cursor=1",
     "SPEECH OUTPUT: 'push button'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_Enter"))
sequence.append(utils.AssertPresentationAction(
    "6. Where Am I",
    ["BRAILLE LINE:  'gtk3-demo-application application Application Class frame push button'",
     "     VISIBLE:  'push button', cursor=1",
     "SPEECH OUTPUT: 'tool bar push button'"]))

sequence.append(KeyComboAction("<Alt>F4"))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
